@@ -11,10 +11,6 @@ from .parts.AES_crypt import AESCipher
 
 revived_file_dir = "./__tskr_revived__/"
 
-file_pool_dir = "./file_pool/"
-# with open(rel2abs("./file_pool_path.txt"), "r", encoding = "utf-8") as f:
-# 	file_pool_dir = f.read().strip()
-
 # 16進数の乱数を生成
 def gen_16_rand(n):
 	ls16 = "0123456789abcdef"
@@ -23,7 +19,7 @@ def gen_16_rand(n):
 	return "".join(ret_ls)
 
 # tskr形式で保存
-def tskr_save(org_filename):
+def tskr_save(org_filename, file_pool_dir):
 	# ファイルのidとkeyを作成
 	file_id = gen_16_rand(n = 16)	# 16進数の乱数を生成
 	file_key = gen_16_rand(n = 32)	# 16進数の乱数を生成
@@ -43,12 +39,13 @@ def tskr_save(org_filename):
 	bind_obj = aesc.encrypt(base64_str).encode()
 	# 対象の保存
 	pool_filename = "%s/%s.tskr"%(file_pool_dir, file_id)
+	fileinit(pool_filename, overwrite = True)
 	with open(pool_filename, "wb") as f:
 		f.write(bind_obj)
 	return file_acc
 
 # tskr形式のファイルを開く
-def tskr_open(file_acc):
+def tskr_open(file_acc, file_pool_dir):
 	# ファイル指定子(file_acc)の解釈
 	acc_ls = file_acc.split("_")
 	if acc_ls[0] != "tskr": raise Exception("[ERROR] ファイル指定子の形式が不正です")
@@ -74,24 +71,40 @@ def tskr_open(file_acc):
 def tskr():
 	# コマンドライン引数
 	argv_ls = sys.argv
-	# モード切替
+	# 存在しない場合にpath_fileを生成する
+	path_file = "./file_pool_path.txt"
+	fileinit(path_file, overwrite = False)
+	### pool_path書き換えモード
+	if len(argv_ls) == 2 and argv_ls[1] == "--poolpath":
+		with open(rel2abs(path_file), "w", encoding = "utf-8") as f:
+			f.write(argv_ls[2])
+		print("file_pool_pathを設定しました")
+		return None
+	### file_pool_pathの読み込み
+	with open(rel2abs(path_file), "r", encoding = "utf-8") as f:
+		file_pool_dir = f.read().strip()
+	if file_pool_dir == "":
+		print("file_pool_pathが設定されていません。オプション引数「--poolpath」を使って設定してください。")
+		return None
+	### 保存モード
 	if len(argv_ls) == 2:
-		### 保存モード
 		# 保存対象ファイル名の取得
 		org_filename = argv_ls[1]
 		# tskr形式で保存
-		file_acc = tskr_save(org_filename)
+		file_acc = tskr_save(org_filename, file_pool_dir)
 		# ファイル指定子(file_acc)の表示
 		print("ファイル指定子は以下のとおりです:")
 		print("\n%s\n"%file_acc)
 		print("【！】忘れずにクリップボード等にコピーしてください")
-	else:
-		### 開くモード
+		input("[Enter] で終了...")
+	### 開くモード
+	if len(argv_ls) == 1:
 		# 対象の入力
 		print("※ファイルをtskr形式に変換する際は、コマンドライン引数でファイル名を指定してください")
 		file_acc = input("ファイル指定子>")
 		# tskr形式のファイルを開く
-		tskr_open(file_acc)
+		tskr_open(file_acc, file_pool_dir)
+		return None
 
 # # モジュールオブジェクトと関数を同一視
 # sys.modules[__name__] = tskr
